@@ -18,23 +18,23 @@ def parse(sentence_list):
             input_list.append(sentence.rchild)
 
         elif type(sentence) is Disjunction:
-            if (~sentence.lchild).validate(input_list + parsed_list):
+            if (~sentence.lchild).validate(set(input_list + parsed_list)):
                 input_list.append(sentence.rchild)
-            elif (~sentence.rchild).validate(input_list + parsed_list):
+            elif (~sentence.rchild).validate(set(input_list + parsed_list)):
                 input_list.append(sentence.lchild)
 
         elif type(sentence) is Implication:
-            if sentence.lchild.validate(input_list + parsed_list):
+            if sentence.lchild.validate(set(input_list + parsed_list)):
                 input_list.append(sentence.rchild)
 
         elif type(sentence) is Equality:
-            if sentence.lchild.validate(input_list + parsed_list):
+            if sentence.lchild.validate(set(input_list + parsed_list)):
                 input_list.append(sentence.rchild)
-            elif sentence.rchild.validate(input_list + parsed_list):
+            elif sentence.rchild.validate(set(input_list + parsed_list)):
                 input_list.append(sentence.lchild)
-            elif (~sentence.lchild).validate(input_list + parsed_list):
+            elif (~sentence.lchild).validate(set(input_list + parsed_list)):
                 input_list.append(~sentence.rchild)
-            elif (~sentence.rchild).validate(input_list + parsed_list):
+            elif (~sentence.rchild).validate(set(input_list + parsed_list)):
                 input_list.append(~sentence.lchild)
 
     return set(parsed_list)
\ No newline at end of file
